@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: qbcfgtabpageaccounts.cpp 857 2006-01-26 03:34:55Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -155,6 +155,7 @@ void QBCfgTabPageAccounts::slotAccountNew() {
       DBG_INFO(0, "Accepted, adding account");
       AB_Banking_AddAccount(getBanking()->getCInterface(), a);
       updateView();
+      emit signalUpdate();
     }
     else {
       DBG_INFO(0, "Rejected");
@@ -173,8 +174,9 @@ void QBCfgTabPageAccounts::slotAccountEdit() {
   if (al.empty()) {
     QMessageBox::critical(this,
                           tr("Selection Error"),
-                          tr("No user selected.\n"),
+                          tr("No account selected."),
                           QMessageBox::Retry,QMessageBox::NoButton);
+    return;
   }
   a=al.front();
   if (QBEditAccount::editAccount(getBanking(), a, this)) {
@@ -183,12 +185,42 @@ void QBCfgTabPageAccounts::slotAccountEdit() {
   else {
     DBG_INFO(0, "Rejected");
   }
+  emit signalUpdate();
   updateView();
 }
 
 
 
 void QBCfgTabPageAccounts::slotAccountDel() {
+  std::list<AB_ACCOUNT*> al =
+    _realPage->accountList->getSelectedAccounts();
+  if (al.empty()) {
+    QMessageBox::critical(this,
+                          tr("Selection Error"),
+                          tr("No account selected."),
+                          QMessageBox::Retry,QMessageBox::NoButton);
+    return;
+  }
+  AB_ACCOUNT *a = al.front();
+  int r = QMessageBox::warning(this,
+				tr("Really delete account?"),
+				tr("You are about to delete an account. This action will "
+				   "take effect immediately and cannot be undone. "
+				   "(You can add the account later again, of course.)\n\n"
+				   "Do you want to delete this account?"),
+				QMessageBox::Yes,QMessageBox::Abort);
+  if (r != 0 && r != QMessageBox::Yes) {
+    return;
+  }
+  int rv = AB_Banking_DeleteAccount(getBanking()->getCInterface(), a);
+  if (rv == 0) {
+    DBG_INFO(0, "Accepted");
+  }
+  else {
+    DBG_INFO(0, "Rejected");
+  }
+  emit signalUpdate();
+  updateView();
 }
 
 
@@ -199,5 +231,12 @@ void QBCfgTabPageAccounts::updateView() {
 
 
 
+void QBCfgTabPageAccounts::slotUpdate() {
+  DBG_INFO(AQBANKING_LOGDOMAIN, "Updating accounts view");
+  updateView();
+}
+
+
+
 #include "qbcfgtabpageaccounts.moc"
 
