@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: qbcfgtabsettings.cpp 837 2006-01-23 16:31:01Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -28,6 +28,7 @@
 
 // Gwenhywfar includes
 #include <gwenhywfar/types.h>
+#include <gwenhywfar/debug.h>
 
 
 
@@ -55,6 +56,10 @@ void QBCfgTabSettings::addAccountsPage() {
   QBCfgTabPageAccounts *p;
 
   p=new QBCfgTabPageAccounts(getBanking(), this);
+  connect(p, SIGNAL(signalUpdate()),
+	  this, SLOT(slotUpdate()));
+  connect(this, SIGNAL(signalUpdate()),
+	  p, SLOT(slotUpdate()));
   addPage(p);
 }
 
@@ -64,6 +69,10 @@ void QBCfgTabSettings::addUsersPage() {
   QBCfgTabPageUsers *p;
 
   p=new QBCfgTabPageUsers(getBanking(), this);
+  connect(p, SIGNAL(signalUpdate()),
+	  this, SLOT(slotUpdate()));
+  connect(this, SIGNAL(signalUpdate()),
+	  p, SLOT(slotUpdate()));
   addPage(p);
 }
 
@@ -73,6 +82,10 @@ void QBCfgTabSettings::addBackendsPage() {
   QBCfgTabPageBackends *p;
 
   p=new QBCfgTabPageBackends(getBanking(), this);
+  connect(p, SIGNAL(signalUpdate()),
+	  this, SLOT(slotUpdate()));
+  connect(this, SIGNAL(signalUpdate()),
+	  p, SLOT(slotUpdate()));
   addPage(p);
 }
 
@@ -82,6 +95,8 @@ void QBCfgTabSettings::addBackendsPage() {
 
 
 void QBCfgTabSettings::slotUpdate() {
+  DBG_INFO(AQBANKING_LOGDOMAIN, "Updating all tabs");
+  emit signalUpdate();
 }
 
 
