@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: qbjoblist.cpp 809 2006-01-20 14:15:15Z cstim $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -124,6 +124,9 @@ void QBJobListViewItem::_populate() {
   case AB_Job_TypeInternalTransfer:
     tmp=QWidget::tr("Internal Transfer");
     break;
+  case AB_Job_TypeLoadCellPhone:
+    tmp=QWidget::tr("Load Cellphone");
+    break;
 
   case AB_Job_TypeUnknown:
     tmp=QWidget::tr("(unknown)");
