@@ -27,13 +27,30 @@ struct AB_ACCOUNT {
   GWEN_INHERIT_ELEMENT(AB_ACCOUNT)
   GWEN_LIST_ELEMENT(AB_ACCOUNT)
   uint32_t usage;
+
   uint32_t uniqueId;
   AB_ACCOUNT_TYPE accountType;
 
   AB_BANKING *banking;
   AB_PROVIDER *provider;
   char *backendName;
-  GWEN_DB_NODE *data;
+
+  char *accountNumber;
+  char *bankCode;
+  char *accountName;
+  char *bankName;
+  char *iban;
+  char *bic;
+  char *ownerName;
+  char *currency;
+  char *country;
+
+  GWEN_STRINGLIST *userIds;
+  GWEN_STRINGLIST *selectedUserIds;
+
+  GWEN_DB_NODE *appData;
+  GWEN_DB_NODE *providerData;
+
 };
 
 static AB_ACCOUNT *AB_Account__freeAll_cb(AB_ACCOUNT *a, void *userData);
