@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: banking_be.h 953 2006-02-24 03:07:59Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 /** @file banking_be.h
@@ -18,9 +19,10 @@
 #ifndef AQBANKING_BANKING_BE_H
 #define AQBANKING_BANKING_BE_H
 
-#include <gwenhywfar/nl_ssl.h>
 #include <aqbanking/banking.h>
 
+
+
 /** @addtogroup G_AB_BE_BANKING
  */
 /*@{*/
@@ -47,10 +49,10 @@ AB_PROVIDER *AB_Banking_GetProvider(AB_BANKING *ab, const char *name);
 
 /**
  * Returns the list of global data folders. In most cases this is something
- * like $PREFIX/share/aqbanking. Plugins are required to use the folders
- * returned here when searching for their specific data instead of using the
- * compile time fixed values. This way it is easier under windows to find
- * data.
+ * like $PREFIX/share/. Plugins are required to use the folders
+ * returned here + "aqbanking" when searching for their specific data instead
+ * of using the compile time fixed values. This way it is easier under
+ * windows to find data.
  */
 AQBANKING_API
 GWEN_STRINGLIST *AB_Banking_GetGlobalDataDirs();
@@ -62,15 +64,35 @@ GWEN_STRINGLIST *AB_Banking_GetGlobalSysconfDirs();
 /*@}*/
 
 
-AQBANKING_API
-GWEN_NL_SSL_ASKADDCERT_RESULT
-  AB_Banking_AskAddCert(GWEN_NETLAYER *nl,
-                        const GWEN_SSLCERTDESCR *cd,
-                        void *user_data);
+
+/** @name Administration of Crypt Token List
+ *
+ */
+/*@{*/
+AQBANKING_API 
+int AB_Banking_GetCryptToken(AB_BANKING *ab,
+			     const char *tname,
+			     const char *cname,
+			     GWEN_CRYPT_TOKEN **pCt);
+
+AQBANKING_API 
+void AB_Banking_ClearCryptTokenList(AB_BANKING *ab, uint32_t guiid);
+
+AQBANKING_API 
+int AB_Banking_CheckCryptToken(AB_BANKING *ab,
+			       GWEN_CRYPT_TOKEN_DEVICE devt,
+			       GWEN_BUFFER *typeName,
+			       GWEN_BUFFER *tokenName,
+			       uint32_t guiid);
+
+/*@}*/
 
 
 AQBANKING_API
-int AB_Banking_ExecutionProgress(AB_BANKING *ab, GWEN_TYPE_UINT32 pid);
+int AB_Banking_ExecutionProgress(AB_BANKING *ab, uint32_t pid);
+
+AQBANKING_API
+uint32_t AB_Banking_GetUniqueId(AB_BANKING *ab);
 
 
 #ifdef __cplusplus
