@@ -115,27 +115,12 @@ int AB_Banking__ExecuteQueue(AB_BANKING *ab,
                  AB_Provider_GetName(pro));
       rv=AB_Provider_Execute(pro, ctx, pid);
       if (rv) {
-        int lrv;
-
 	if (rv==GWEN_ERROR_USER_ABORTED) {
           DBG_INFO(AQBANKING_LOGDOMAIN, "Aborted by user");
           ab->currentJobs=0;
           return rv;
         }
         DBG_NOTICE(AQBANKING_LOGDOMAIN, "Error executing backend's queue");
-        lrv=GWEN_Gui_MessageBox(GWEN_GUI_MSG_FLAGS_TYPE_ERROR |
-				GWEN_GUI_MSG_FLAGS_CONFIRM_B1 |
-				GWEN_GUI_MSG_FLAGS_SEVERITY_NORMAL,
-				I18N("Error"),
-				I18N("Error executing backend's queue.\n"
-				     "What shall we do?"),
-				I18N("Continue"), I18N("Abort"), 0,
-				pid);
-	if (lrv!=1) {
-	  DBG_INFO(AQBANKING_LOGDOMAIN, "Aborted by user");
-	  ab->currentJobs=0;
-	  return GWEN_ERROR_USER_ABORTED;
-	}
       }
       else {
 	rv=AB_Banking_ExecutionProgress(ab, pid);
@@ -978,3 +963,92 @@ int AB_Banking_CheckCryptToken(AB_BANKING *ab,
 
 
 
+void AB_Banking__fillTransactionFromAccount(AB_TRANSACTION *t, const AB_ACCOUNT *a) {
+  const char *s;
+
+  s=AB_Transaction_GetLocalName(t);
+  if (!s)
+    AB_Transaction_SetLocalName(t, AB_Account_GetOwnerName(a));
+  s=AB_Transaction_GetLocalBankCode(t);
+  if (!s)
+    AB_Transaction_SetLocalBankCode(t, AB_Account_GetBankCode(a));
+  s=AB_Transaction_GetLocalAccountNumber(t);
+  if (!s)
+    AB_Transaction_SetLocalAccountNumber(t, AB_Account_GetAccountNumber(a));
+  s=AB_Transaction_GetLocalIban(t);
+  if (!s)
+    AB_Transaction_SetLocalIban(t, AB_Account_GetIBAN(a));
+  s=AB_Transaction_GetLocalBic(t);
+  if (!s)
+    AB_Transaction_SetLocalBic(t, AB_Account_GetBIC(a));
+}
+
+
+
+int AB_Banking_FillGapsInImExporterContext(AB_BANKING *ab, AB_IMEXPORTER_CONTEXT *iec) {
+  AB_IMEXPORTER_ACCOUNTINFO *iea;
+  int notFounds=0;
+
+  assert(iec);
+  iea=AB_ImExporterContext_GetFirstAccountInfo(iec);
+  while(iea) {
+    AB_ACCOUNT *a;
+
+    a=AB_Banking_GetAccountByCodeAndNumber(ab,
+					   AB_ImExporterAccountInfo_GetBankCode(iea),
+					   AB_ImExporterAccountInfo_GetAccountNumber(iea));
+    if (!a)
+      a=AB_Banking_GetAccountByIban(ab, AB_ImExporterAccountInfo_GetIban(iea));
+    if (a) {
+      AB_TRANSACTION *t;
+
+      AB_ImExporterAccountInfo_FillFromAccount(iea, a);
+
+      /* fill transactions */
+      t=AB_ImExporterAccountInfo_GetFirstTransaction(iea);
+      while(t) {
+	AB_Banking__fillTransactionFromAccount(t, a);
+	t=AB_ImExporterAccountInfo_GetNextTransaction(iea);
+      }
+
+      /* fill standing orders */
+      t=AB_ImExporterAccountInfo_GetFirstStandingOrder(iea);
+      while(t) {
+	AB_Banking__fillTransactionFromAccount(t, a);
+	t=AB_ImExporterAccountInfo_GetNextStandingOrder(iea);
+      }
+
+      /* fill transfers */
+      t=AB_ImExporterAccountInfo_GetFirstTransfer(iea);
+      while(t) {
+	AB_Banking__fillTransactionFromAccount(t, a);
+	t=AB_ImExporterAccountInfo_GetNextTransfer(iea);
+      }
+
+      /* fill dated transfers */
+      t=AB_ImExporterAccountInfo_GetFirstDatedTransfer(iea);
+      while(t) {
+	AB_Banking__fillTransactionFromAccount(t, a);
+	t=AB_ImExporterAccountInfo_GetNextDatedTransfer(iea);
+      }
+
+      /* fill noted transactions */
+      t=AB_ImExporterAccountInfo_GetFirstNotedTransaction(iea);
+      while(t) {
+	AB_Banking__fillTransactionFromAccount(t, a);
+	t=AB_ImExporterAccountInfo_GetNextNotedTransaction(iea);
+      }
+    }
+    else
+      notFounds++;
+
+    iea=AB_ImExporterContext_GetNextAccountInfo(iec);
+  }
+
+  return (notFounds==0)?0:1;
+}
+
+
+
+
+
