@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: cryptmanager_p.h 829 2006-01-23 05:16:27Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -21,16 +22,16 @@
 typedef struct AB_CRYPTMANAGER AB_CRYPTMANAGER;
 struct AB_CRYPTMANAGER {
   AB_BANKING *banking;
-  GWEN_TYPE_UINT32 showBoxId;
+  uint32_t showBoxId;
 };
-static void AB_CryptManager_FreeData(void *bp, void *p);
+static void GWENHYWFAR_CB AB_CryptManager_FreeData(void *bp, void *p);
 
 
 static int AB_CryptManager_GetPin(GWEN_PLUGIN_MANAGER *cm,
                                   GWEN_CRYPTTOKEN *token,
                                   GWEN_CRYPTTOKEN_PINTYPE pt,
                                   GWEN_CRYPTTOKEN_PINENCODING pe,
-                                  GWEN_TYPE_UINT32 flags,
+                                  uint32_t flags,
                                   unsigned char *buffer,
                                   unsigned int minLength,
                                   unsigned int maxLength,
@@ -40,29 +41,11 @@ static int AB_CryptManager_SetPinStatus(GWEN_PLUGIN_MANAGER *pm,
                                         GWEN_CRYPTTOKEN *token,
                                         GWEN_CRYPTTOKEN_PINTYPE pt,
                                         GWEN_CRYPTTOKEN_PINENCODING pe,
-                                        GWEN_TYPE_UINT32 flags,
+                                        uint32_t flags,
                                         unsigned char *buffer,
                                         unsigned int pinLength,
                                         int isOk);
 
-static int AB_CryptManager_BeginEnterPin(GWEN_PLUGIN_MANAGER *cm,
-                                         GWEN_CRYPTTOKEN *token,
-                                         GWEN_CRYPTTOKEN_PINTYPE pt);
-static int AB_CryptManager_EndEnterPin(GWEN_PLUGIN_MANAGER *cm,
-                                       GWEN_CRYPTTOKEN *token,
-                                       GWEN_CRYPTTOKEN_PINTYPE pt,
-                                       int ok);
-static int AB_CryptManager_InsertToken(GWEN_PLUGIN_MANAGER *cm,
-                                       GWEN_CRYPTTOKEN *token);
-static int AB_CryptManager_InsertCorrectToken(GWEN_PLUGIN_MANAGER *cm,
-                                              GWEN_CRYPTTOKEN *token);
-
-static int AB_CryptManager_ShowMessage(GWEN_PLUGIN_MANAGER *cm,
-                                       GWEN_CRYPTTOKEN *token,
-                                       const char *title,
-                                       const char *msg);
-
-
 
 
 #endif /* AQBANKING_CRYPTMANAGER_P_H */
