@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: imexporter_p.h 1028 2006-05-29 16:59:15Z martin $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -48,6 +49,13 @@ struct AB_IMEXPORTER_CONTEXT {
   AB_IMEXPORTER_ACCOUNTINFO_LIST *accountInfoList;
   AB_IMEXPORTER_ACCOUNTINFO *nextAccountInfo;
 
+  AB_SECURITY_LIST *securityList;
+  AB_SECURITY *nextSecurity;
+
+  AB_MESSAGE_LIST *messageList;
+  AB_MESSAGE *nextMessage;
+
+  GWEN_BUFFER *logs;
 };
 
 
@@ -59,6 +67,7 @@ struct AB_IMEXPORTER_ACCOUNTINFO {
   char *accountNumber;
   char *accountName;
   char *iban;
+  char *bic;
   char *owner;
   char *currency;
   char *description;
@@ -91,6 +100,14 @@ static int AH_ImExporter__Transform_Group(GWEN_DB_NODE *db, int level);
 
 
 
+typedef struct AB_PLUGIN_IMEXPORTER AB_PLUGIN_IMEXPORTER;
+struct AB_PLUGIN_IMEXPORTER {
+  AB_PLUGIN_IMEXPORTER_FACTORY_FN pluginFactoryFn;
+};
+
+static void AB_Plugin_ImExporter_FreeData(void *bp, void *p);
+
+
 #endif /* AQBANKING_IMEXPORTER_P_H */
 
 
