@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: job_p.h 933 2006-02-10 12:10:18Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -29,10 +30,10 @@ struct AB_JOB {
   char *resultText;
   AB_JOB_TYPE jobType;
   int availability;
-  GWEN_TYPE_UINT32 jobId;
-  GWEN_TYPE_UINT32 usage;
+  uint32_t jobId;
+  uint32_t usage;
   char *createdBy;
-  GWEN_TYPE_UINT32 idForProvider;
+  uint32_t idForProvider;
   GWEN_DB_NODE *dbData;
   GWEN_TIME *lastStatusChange;
   char *usedTan;
@@ -41,5 +42,4 @@ static AB_JOB *AB_Job__freeAll_cb(AB_JOB *j, void *userData);
 
 
 
-
 #endif /* AQBANKING_JOB_P_H */
