@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: jobcreatesto.c 355 2005-07-09 14:05:22Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -57,16 +58,3 @@ const AB_TRANSACTION *AB_JobCreateStandingOrder_GetTransaction(const AB_JOB *j){
 
 
 
-int AB_JobCreateStandingOrder_toDb(const AB_JOB *j, GWEN_DB_NODE *db) {
-  return AB_JobTransferBase_toDb(j, db);
-}
-
-
-
-AB_JOB *AB_JobCreateStandingOrder_fromDb(AB_ACCOUNT *a, GWEN_DB_NODE *db) {
-  return AB_JobTransferBase_fromDb(AB_Job_TypeCreateStandingOrder, a, db);
-}
-
-
-
-
