@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: provider_p.h 933 2006-02-10 12:10:18Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -45,11 +46,20 @@ struct AB_PROVIDER {
 
   GWEN_PLUGIN *plugin;
 
-  GWEN_TYPE_UINT32 usage;
-  GWEN_TYPE_UINT32 flags;
+  uint32_t usage;
+  uint32_t flags;
   int isInit;
 };
 
 
 
+typedef struct AB_PLUGIN_PROVIDER AB_PLUGIN_PROVIDER;
+struct AB_PLUGIN_PROVIDER {
+  AB_PLUGIN_PROVIDER_FACTORY_FN pluginFactoryFn;
+};
+
+static void AB_Plugin_Provider_FreeData(void *bp, void *p);
+
+
+
 #endif /* AQBANKING_PROVIDER_P_H */
