@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: accstatus.c 764 2006-01-13 14:00:00Z cstim $
+    cvs         : $Id$
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
@@ -67,7 +68,7 @@ AB_ACCOUNT_STATUS *AB_AccountStatus_dup(const AB_ACCOUNT_STATUS *as){
 
 AB_ACCOUNT_STATUS *AB_AccountStatus_fromDb(GWEN_DB_NODE *db){
   AB_ACCOUNT_STATUS *as;
-  GWEN_TYPE_UINT32 i;
+  uint32_t i;
   GWEN_DB_NODE *tdb;
 
   GWEN_NEW_OBJECT(AB_ACCOUNT_STATUS, as);
@@ -172,7 +173,8 @@ void AB_AccountStatus_SetTime(AB_ACCOUNT_STATUS *as,
                               const GWEN_TIME *t){
   assert(as);
   GWEN_Time_free(as->time);
-  as->time=GWEN_Time_dup(t);
+  if (t) as->time=GWEN_Time_dup(t);
+  else as->time=NULL;
 }
 
 
@@ -189,7 +191,8 @@ void AB_AccountStatus_SetBankLine(AB_ACCOUNT_STATUS *as,
                                   const AB_VALUE *v){
   assert(as);
   AB_Value_free(as->bankLine);
-  as->bankLine=AB_Value_dup(v);
+  if (v) as->bankLine=AB_Value_dup(v);
+  else as->bankLine=NULL;
 }
 
 
@@ -206,7 +209,8 @@ void AB_AccountStatus_SetDisposable(AB_ACCOUNT_STATUS *as,
                                     const AB_VALUE *v){
   assert(as);
   AB_Value_free(as->disposable);
-  as->disposable=AB_Value_dup(v);
+  if (v) as->disposable=AB_Value_dup(v);
+  else as->disposable=NULL;
 }
 
 
@@ -223,7 +227,8 @@ void AB_AccountStatus_SetDisposed(AB_ACCOUNT_STATUS *as,
                                   const AB_VALUE *v){
   assert(as);
   AB_Value_free(as->disposed);
-  as->disposed=AB_Value_dup(v);
+  if (v) as->disposed=AB_Value_dup(v);
+  else as->disposed=NULL;
 }
 
 
@@ -240,7 +245,8 @@ void AB_AccountStatus_SetBookedBalance(AB_ACCOUNT_STATUS *as,
                                        const AB_BALANCE *b){
   assert(as);
   AB_Balance_free(as->bookedBalance);
-  as->bookedBalance=AB_Balance_dup(b);
+  if (b) as->bookedBalance=AB_Balance_dup(b);
+  else as->bookedBalance=NULL;
 }
 
 
@@ -257,7 +263,8 @@ void AB_AccountStatus_SetNotedBalance(AB_ACCOUNT_STATUS *as,
                                       const AB_BALANCE *b){
   assert(as);
   AB_Balance_free(as->notedBalance);
-  as->notedBalance=AB_Balance_dup(b);
+  if (b) as->notedBalance=AB_Balance_dup(b);
+  else as->notedBalance=NULL;
 }
 
 
