@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: jobgettransactions_p.h 950 2006-02-22 19:39:02Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -23,18 +23,22 @@ typedef struct AH_JOB_GETTRANSACTIONS AH_JOB_GETTRANSACTIONS;
 struct AH_JOB_GETTRANSACTIONS {
   int dummy;
 };
-static void AH_Job_GetTransactions_FreeData(void *bp, void *p);
+static void GWENHYWFAR_CB AH_Job_GetTransactions_FreeData(void *bp, void *p);
 static int AH_Job_GetTransactions_Process(AH_JOB *j,
-                                          AB_IMEXPORTER_CONTEXT *ctx);
+					  AB_IMEXPORTER_CONTEXT *ctx,
+					  uint32_t guiid);
 static int AH_Job_GetTransactions_Exchange(AH_JOB *j, AB_JOB *bj,
-                                           AH_JOB_EXCHANGE_MODE m);
+					   AH_JOB_EXCHANGE_MODE m,
+					   AB_IMEXPORTER_CONTEXT *ctx,
+					   uint32_t guiid);
 
 static int
   AH_Job_GetTransactions__ReadTransactions(AH_JOB *j,
                                            AB_IMEXPORTER_ACCOUNTINFO *ai,
                                            const char *docType,
                                            int noted,
-                                           GWEN_BUFFER *buf);
+					   GWEN_BUFFER *buf,
+					   uint32_t guiid);
 
 
 
