@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: jobmultitransfer_p.h 935 2006-02-14 02:11:55Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -25,12 +25,19 @@ struct AH_JOB_MULTITRANSFER {
   int isTransfer;
   int transferCount;
   int maxTransfers;
+
+  AB_VALUE *sumRemoteAccountId;
+  AB_VALUE *sumValues;
 };
-static void AH_Job_MultiTransfer_FreeData(void *bp, void *p);
+static void GWENHYWFAR_CB AH_Job_MultiTransfer_FreeData(void *bp, void *p);
 static int AH_Job_MultiTransfer_Process(AH_JOB *j,
-                                        AB_IMEXPORTER_CONTEXT *ctx);
+					AB_IMEXPORTER_CONTEXT *ctx,
+					uint32_t guiid);
 static int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
-                                         AH_JOB_EXCHANGE_MODE m);
+					 AH_JOB_EXCHANGE_MODE m,
+					 AB_IMEXPORTER_CONTEXT *ctx,
+					 uint32_t guiid);
+static int AH_Job_MultiTransfer_Prepare(AH_JOB *j, uint32_t guiid);
 
 
 static int AH_Job_MultiTransfer__ValidateTransfer(AB_JOB *bj,
