@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: jobsingletransfer.c 935 2006-02-14 02:11:55Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -51,8 +51,13 @@ GWEN_INHERIT(AH_JOB, AH_JOB_SINGLETRANSFER);
 
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_SingleTransfer_new(AB_USER *u,
-                                  AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account, AB_Job_TypeTransfer);
+				  AB_ACCOUNT *account) {
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account, AB_Job_TypeTransfer);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -60,7 +65,12 @@ AH_JOB *AH_Job_SingleTransfer_new(AB_USER *u,
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_SingleDebitNote_new(AB_USER *u,
                                    AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account, AB_Job_TypeDebitNote);
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account, AB_Job_TypeDebitNote);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -68,8 +78,13 @@ AH_JOB *AH_Job_SingleDebitNote_new(AB_USER *u,
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_CreateStandingOrder_new(AB_USER *u,
                                        AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account,
-                                       AB_Job_TypeCreateStandingOrder);
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account,
+				  AB_Job_TypeCreateStandingOrder);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -77,8 +92,13 @@ AH_JOB *AH_Job_CreateStandingOrder_new(AB_USER *u,
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_ModifyStandingOrder_new(AB_USER *u,
                                        AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account,
-                                       AB_Job_TypeModifyStandingOrder);
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account,
+				  AB_Job_TypeModifyStandingOrder);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -86,8 +106,13 @@ AH_JOB *AH_Job_ModifyStandingOrder_new(AB_USER *u,
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_DeleteStandingOrder_new(AB_USER *u,
                                        AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account,
-                                       AB_Job_TypeDeleteStandingOrder);
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account,
+				  AB_Job_TypeDeleteStandingOrder);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -95,8 +120,13 @@ AH_JOB *AH_Job_DeleteStandingOrder_new(AB_USER *u,
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_CreateDatedTransfer_new(AB_USER *u,
                                        AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account,
-                                       AB_Job_TypeCreateDatedTransfer);
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account,
+				  AB_Job_TypeCreateDatedTransfer);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -104,8 +134,13 @@ AH_JOB *AH_Job_CreateDatedTransfer_new(AB_USER *u,
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_ModifyDatedTransfer_new(AB_USER *u,
                                        AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account,
-                                       AB_Job_TypeModifyDatedTransfer);
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account,
+				  AB_Job_TypeModifyDatedTransfer);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -113,8 +148,13 @@ AH_JOB *AH_Job_ModifyDatedTransfer_new(AB_USER *u,
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_DeleteDatedTransfer_new(AB_USER *u,
                                        AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account,
-                                       AB_Job_TypeDeleteDatedTransfer);
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account,
+				  AB_Job_TypeDeleteDatedTransfer);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -122,8 +162,13 @@ AH_JOB *AH_Job_DeleteDatedTransfer_new(AB_USER *u,
 /* --------------------------------------------------------------- FUNCTION */
 AH_JOB *AH_Job_InternalTransfer_new(AB_USER *u,
                                     AB_ACCOUNT *account) {
-  return AH_Job_SingleTransferBase_new(u, account,
-                                       AB_Job_TypeInternalTransfer);
+  AH_JOB *j;
+
+  j=AH_Job_SingleTransferBase_new(u, account,
+				  AB_Job_TypeInternalTransfer);
+  if (j)
+    AH_Job_SetChallengeClass(j, 10);
+  return j;
 }
 
 
@@ -191,7 +236,7 @@ AH_JOB *AH_Job_SingleTransferBase_new(AB_USER *u,
 
 
 /* --------------------------------------------------------------- FUNCTION */
-void AH_Job_SingleTransfer_FreeData(void *bp, void *p){
+void GWENHYWFAR_CB AH_Job_SingleTransfer_FreeData(void *bp, void *p){
   AH_JOB_SINGLETRANSFER *aj;
 
   aj=(AH_JOB_SINGLETRANSFER*)p;
@@ -230,7 +275,8 @@ const char *AH_Job_SingleTransfer_GetOldFiid(AH_JOB *j) {
 
 
 /* --------------------------------------------------------------- FUNCTION */
-int AH_Job_SingleTransfer_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
+int AH_Job_SingleTransfer_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+				  uint32_t guiid){
   AH_JOB_SINGLETRANSFER *aj;
   GWEN_DB_NODE *dbResponses;
   GWEN_DB_NODE *dbCurr;
@@ -480,20 +526,13 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
     return -1;
   }
 
-  /* collapse splits if any */
-  n=AB_Split_List_GetCount(AB_Transaction_GetSplits(t));
-  if (n) {
-    DBG_ERROR(AQHBCI_LOGDOMAIN,
-	      "Transfer contains splits, unable to handle");
-    return -1;
-  }
-
   /* check purpose */
   if (lim) {
     maxn=AB_TransactionLimits_GetMaxLinesPurpose(lim);
     maxs=AB_TransactionLimits_GetMaxLenPurpose(lim);
   }
   else {
+    DBG_INFO(AQHBCI_LOGDOMAIN, "No transaction limits");
     maxn=0;
     maxs=0;
   }
@@ -518,18 +557,19 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
 	  DBG_ERROR(AQHBCI_LOGDOMAIN,
 		    "Too many purpose lines (%d>%d)", n, maxn);
 	  GWEN_StringList_free(nsl);
-	  return AB_ERROR_INVALID;
+	  return GWEN_ERROR_INVALID;
 	}
 	tbuf=GWEN_Buffer_new(0, maxs, 0, 1);
 	AB_ImExporter_Utf8ToDta(p, -1, tbuf);
+	GWEN_Text_CondenseBuffer(tbuf);
 	l=GWEN_Buffer_GetUsedBytes(tbuf);
-	if (l>maxs) {
+	if (maxs && l>maxs) {
 	  DBG_ERROR(AQHBCI_LOGDOMAIN,
 		    "Too many chars in purpose line %d (%d>%d)", n, l, maxs);
 	  GWEN_StringList_free(nsl);
-	  return AB_ERROR_INVALID;
+	  return GWEN_ERROR_INVALID;
 	}
-	np=(char*)malloc(l+1);
+	np=(char*)GWEN_Memory_malloc(l+1);
 	memmove(np, GWEN_Buffer_GetStart(tbuf), l+1);
 	GWEN_Buffer_free(tbuf);
 	/* let string list take the newly alllocated string */
@@ -541,7 +581,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
   }
   if (!n) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "No purpose lines");
-    return AB_ERROR_INVALID;
+    return GWEN_ERROR_INVALID;
   }
 
   /* check remote name */
@@ -575,19 +615,20 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
 		    "Too many remote name lines (%d>%d)",
 		    n, maxn);
           GWEN_StringList_free(nsl);
-	  return AB_ERROR_INVALID;
+	  return GWEN_ERROR_INVALID;
 	}
 	tbuf=GWEN_Buffer_new(0, maxs, 0, 1);
         AB_ImExporter_Utf8ToDta(p, -1, tbuf);
+	GWEN_Text_CondenseBuffer(tbuf);
 	l=GWEN_Buffer_GetUsedBytes(tbuf);
 	if (l>maxs) {
 	  DBG_ERROR(AQHBCI_LOGDOMAIN,
 		   "Too many chars in remote name line %d (%d>%d)",
 		   n, l, maxs);
           GWEN_StringList_free(nsl);
-	  return AB_ERROR_INVALID;
+	  return GWEN_ERROR_INVALID;
 	}
-	np=(char*)malloc(l+1);
+	np=(char*)GWEN_Memory_malloc(l+1);
 	memmove(np, GWEN_Buffer_GetStart(tbuf), l+1);
 	GWEN_Buffer_free(tbuf);
 	/* let string list take the newly alllocated string */
@@ -599,7 +640,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
   }
   if (!n) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "No remote name lines");
-    return AB_ERROR_INVALID;
+    return GWEN_ERROR_INVALID;
   }
 
   /* check local name */
@@ -615,7 +656,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
     if (!s) {
       DBG_ERROR(AQHBCI_LOGDOMAIN,
 		"No owner name in account, giving up");
-      return AB_ERROR_INVALID;
+      return GWEN_ERROR_INVALID;
     }
     AB_Transaction_SetLocalName(t, s);
   }
@@ -689,7 +730,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
       if (!AB_TransactionLimits_HasValuesTextKey(lim, numbuf)) {
 	DBG_ERROR(AQHBCI_LOGDOMAIN, "Text key \"%s\" not supported by bank",
 		  numbuf);
-	return AB_ERROR_INVALID;
+	return GWEN_ERROR_INVALID;
       }
     }
   }
@@ -716,7 +757,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
           if (n==0) {
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "No cycle given");
-            return AB_ERROR_INVALID;
+            return GWEN_ERROR_INVALID;
           }
 
           snprintf(numbuf, sizeof(numbuf), "%d", n);
@@ -725,7 +766,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "Month day \"%s\" not supported by bank",
                       numbuf);
-            return AB_ERROR_INVALID;
+            return GWEN_ERROR_INVALID;
           }
         }
 
@@ -738,7 +779,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
           if (n==0) {
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "No execution day given");
-            return AB_ERROR_INVALID;
+            return GWEN_ERROR_INVALID;
           }
 
           snprintf(numbuf, sizeof(numbuf), "%d", n);
@@ -747,7 +788,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "Execution month day \"%s\" not supported by bank",
                       numbuf);
-            return AB_ERROR_INVALID;
+            return GWEN_ERROR_INVALID;
           }
         } /* if there are limits */
       }
@@ -763,7 +804,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
           if (n==0) {
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "No cycle given");
-            return AB_ERROR_INVALID;
+            return GWEN_ERROR_INVALID;
           }
 
           snprintf(numbuf, sizeof(numbuf), "%d", n);
@@ -772,7 +813,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "Week day \"%s\" not supported by bank",
                       numbuf);
-            return AB_ERROR_INVALID;
+            return GWEN_ERROR_INVALID;
           }
         } /* if there are limits */
 
@@ -785,7 +826,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
           if (n==0) {
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "No execution day given");
-            return AB_ERROR_INVALID;
+            return GWEN_ERROR_INVALID;
           }
 
           snprintf(numbuf, sizeof(numbuf), "%d", n);
@@ -794,14 +835,14 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "Execution month day \"%s\" not supported by bank",
                       numbuf);
-            return AB_ERROR_INVALID;
+            return GWEN_ERROR_INVALID;
           }
         } /* if there are limits */
       }
       else {
         DBG_ERROR(AQHBCI_LOGDOMAIN,
                   "Unsupported period %d", AB_Transaction_GetPeriod(t));
-        return AB_ERROR_INVALID;
+        return GWEN_ERROR_INVALID;
       }
 
       /* check setup times */
@@ -821,7 +862,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
         if (n && dt<n) {
           DBG_ERROR(AQHBCI_LOGDOMAIN,
                     "Minimum setup time violated");
-          return AB_ERROR_INVALID;
+          return GWEN_ERROR_INVALID;
         }
 
         /* check maximum setup time */
@@ -829,7 +870,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
         if (n && dt>n) {
           DBG_ERROR(AQHBCI_LOGDOMAIN,
                     "Maximum setup time violated");
-          return AB_ERROR_INVALID;
+          return GWEN_ERROR_INVALID;
         }
       }
       break;
@@ -852,7 +893,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
         if (n && dt<n) {
           DBG_ERROR(AQHBCI_LOGDOMAIN,
                     "Minimum setup time violated");
-          return AB_ERROR_INVALID;
+          return GWEN_ERROR_INVALID;
         }
 
         /* check maximum setup time */
@@ -860,7 +901,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
         if (n && dt>n) {
           DBG_ERROR(AQHBCI_LOGDOMAIN,
                     "Maximum setup time violated");
-          return AB_ERROR_INVALID;
+          return GWEN_ERROR_INVALID;
         }
       }
       break;
@@ -881,7 +922,9 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
 
 /* --------------------------------------------------------------- FUNCTION */
 int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
-                                   AH_JOB_EXCHANGE_MODE m){
+				   AH_JOB_EXCHANGE_MODE m,
+				   AB_IMEXPORTER_CONTEXT *ctx,
+				   uint32_t guiid){
   AH_JOB_SINGLETRANSFER *aj;
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Exchanging (%d)", m);
@@ -893,7 +936,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
   if (aj->jobType!=AB_Job_GetType(bj)) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
               "Different job types");
-    return AB_ERROR_INVALID;
+    return GWEN_ERROR_INVALID;
   }
 
   switch(m) {
@@ -906,7 +949,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
     dbParams=AH_Job_GetParams(j);
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "Have this parameters to exchange:");
-    if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevelDebug)
+    if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevel_Debug)
       GWEN_DB_Dump(dbParams, stderr, 2);
 
     /* read limits */
@@ -1175,7 +1218,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
     default:
       DBG_ERROR(AQHBCI_LOGDOMAIN,
                 "Unhandled job type %d", aj->jobType);
-      return AB_ERROR_INVALID;
+      return GWEN_ERROR_INVALID;
     }
 
     if (ot) {
@@ -1191,7 +1234,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 	DBG_ERROR(AQHBCI_LOGDOMAIN,
 		  "Invalid transaction");
 	AB_Job_SetStatus(bj, AB_Job_StatusError);
-	return AB_ERROR_INVALID;
+	return GWEN_ERROR_INVALID;
       }
       /* store the validated transaction back into application job,
        * to allow the application to recognize answers to this job later */
@@ -1226,7 +1269,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
       default:
         DBG_ERROR(AQHBCI_LOGDOMAIN,
                   "Unhandled job type %d", aj->jobType);
-        return AB_ERROR_INVALID;
+        return GWEN_ERROR_INVALID;
       }
 
       dbT=GWEN_DB_GetGroup(dbArgs, GWEN_DB_FLAGS_OVERWRITE_GROUPS,
@@ -1288,7 +1331,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
         assert(dbV);
 
 	nbuf=GWEN_Buffer_new(0, 32, 0, 1);
-	if (GWEN_Text_DoubleToBuffer(AB_Value_GetValue(v),
+	if (GWEN_Text_DoubleToBuffer(AB_Value_GetValueAsDouble(v),
 				     nbuf)) {
 	  DBG_ERROR(AQHBCI_LOGDOMAIN, "Buffer overflow");
           GWEN_Buffer_free(nbuf);
@@ -1427,7 +1470,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
         default:
           DBG_ERROR(AQHBCI_LOGDOMAIN, "Unsupported period %d",
                     AB_Transaction_GetPeriod(t));
-          return AB_ERROR_INVALID;
+          return GWEN_ERROR_INVALID;
         }
         GWEN_DB_SetCharValue(dbT,
                              GWEN_DB_FLAGS_OVERWRITE_VARS,
@@ -1484,11 +1527,15 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
         break;
       } /* switch */
 
+      /* set challenge stuff */
+      AH_Job_SetChallengeClass(j, 10);
+      AH_Job_AddChallengeParam(j, AB_Transaction_GetRemoteAccountNumber(t));
+      AH_Job_SetChallengeValue(j, AB_Transaction_GetValue(t));
     }
     else {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "No transaction");
       AB_Job_SetStatus(bj, AB_Job_StatusError);
-      return AB_ERROR_NO_DATA;
+      return GWEN_ERROR_NO_DATA;
     }
     return 0;
   }
@@ -1499,6 +1546,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
     int has10;
     int has20;
     const AB_TRANSACTION *ot;
+    AB_TRANSACTION_STATUS tStatus;
 
     rl=AH_Job_GetSegResults(j);
     assert(rl);
@@ -1507,16 +1555,19 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
     if (!r) {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "No segment results");
       AB_Job_SetStatus(bj, AB_Job_StatusError);
-      /* return AB_ERROR_NO_DATA; */
+      /* return GWEN_ERROR_NO_DATA; */
       return 0;
     }
     has10=0;
     has20=0;
     while(r) {
-      if (AH_Result_GetCode(r)==10)
-        has10=1;
-      else if (AH_Result_GetCode(r)==20)
-        has20=1;
+      int rcode;
+
+      rcode=AH_Result_GetCode(r);
+      if (rcode <=19)
+	has10=1;
+      else if (rcode>=20 && rcode <=29)
+	has20=1;
       r=AH_Result_List_Next(r);
     }
 
@@ -1552,10 +1603,47 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
       AB_Job_SetStatus(bj, AB_Job_StatusError);
     }
 
+    if (has20)
+      tStatus=AB_Transaction_StatusAccepted;
+    else if (has10)
+      tStatus=AB_Transaction_StatusPending;
+    else
+      tStatus=AB_Transaction_StatusRejected;
+
     switch(aj->jobType) {
     case AB_Job_TypeTransfer:
+      ot=AB_JobSingleTransfer_GetTransaction(bj);
+      if (ot) {
+	AB_TRANSACTION *t;
+
+	t=AB_Transaction_dup(ot);
+	AB_Transaction_SetStatus(t, tStatus);
+	AB_Transaction_SetType(t, AB_Transaction_TypeTransfer);
+	AB_ImExporterContext_AddTransfer(ctx, t);
+      }
+      break;
+
     case AB_Job_TypeDebitNote:
+      ot=AB_JobSingleDebitNote_GetTransaction(bj);
+      if (ot) {
+	AB_TRANSACTION *t;
+
+	t=AB_Transaction_dup(ot);
+	AB_Transaction_SetStatus(t, tStatus);
+	AB_Transaction_SetType(t, AB_Transaction_TypeDebitNote);
+	AB_ImExporterContext_AddTransfer(ctx, t);
+      }
+      break;
+
     case AB_Job_TypeInternalTransfer:
+      ot=AB_JobInternalTransfer_GetTransaction(bj);
+      if (ot) {
+	AB_TRANSACTION *t;
+
+	t=AB_Transaction_dup(ot);
+	AB_Transaction_SetStatus(t, tStatus);
+	AB_ImExporterContext_AddTransfer(ctx, t);
+      }
       break;
 
     case AB_Job_TypeCreateStandingOrder:
@@ -1565,7 +1653,9 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
 	t=AB_Transaction_dup(ot);
 	AB_Transaction_SetFiId(t, aj->fiid);
+	AB_Transaction_SetStatus(t, tStatus);
 	AB_JobCreateStandingOrder_SetTransaction(bj, t);
+        AB_Transaction_free(t);
       }
       break;
 
@@ -1576,7 +1666,9 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
 	t=AB_Transaction_dup(ot);
 	AB_Transaction_SetFiId(t, aj->fiid);
+	AB_Transaction_SetStatus(t, tStatus);
 	AB_JobModifyStandingOrder_SetTransaction(bj, t);
+	AB_Transaction_free(t);
       }
       break;
 
@@ -1590,7 +1682,9 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
 	t=AB_Transaction_dup(ot);
 	AB_Transaction_SetFiId(t, aj->fiid);
+	AB_Transaction_SetStatus(t, tStatus);
 	AB_JobCreateDatedTransfer_SetTransaction(bj, t);
+        AB_Transaction_free(t);
       }
       break;
 
@@ -1601,7 +1695,9 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
 	t=AB_Transaction_dup(ot);
 	AB_Transaction_SetFiId(t, aj->fiid);
+	AB_Transaction_SetStatus(t, tStatus);
 	AB_JobModifyDatedTransfer_SetTransaction(bj, t);
+        AB_Transaction_free(t);
       }
       break;
 
@@ -1619,7 +1715,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
   default:
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Unsupported exchange mode");
-    return AB_ERROR_NOT_SUPPORTED;
+    return GWEN_ERROR_NOT_SUPPORTED;
   } /* switch */
 }
 
