@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: adminjobs_p.h 1042 2006-07-04 01:15:33Z martin $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -26,13 +26,15 @@
 typedef struct AH_JOB_GETKEYS AH_JOB_GETKEYS;
 
 struct AH_JOB_GETKEYS {
-  GWEN_CRYPTKEY *signKey;
-  GWEN_CRYPTKEY *cryptKey;
+  char *peerId;
+  GWEN_CRYPT_TOKEN_KEYINFO *signKeyInfo;
+  GWEN_CRYPT_TOKEN_KEYINFO *cryptKeyInfo;
+  GWEN_CRYPT_TOKEN_KEYINFO *authKeyInfo;
 };
 
-static void AH_Job_GetKeys_FreeData(void *bp, void *p);
-static int AH_Job_GetKeys_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
-static int AH_Job_GetKeys_Commit(AH_JOB *j);
+static void GWENHYWFAR_CB AH_Job_GetKeys_FreeData(void *bp, void *p);
+static int AH_Job_GetKeys_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+				  uint32_t guiid);
 
 
 
@@ -48,7 +50,8 @@ static int AH_Job_GetKeys_Commit(AH_JOB *j);
 
 static int AH_Job_SendKeys_PrepareKey(AH_JOB *j,
                                       GWEN_DB_NODE *dbKey,
-                                      const GWEN_CRYPTKEY *key);
+				      const GWEN_CRYPT_TOKEN_KEYINFO *ki,
+                                      int kn);
 
 
 
@@ -64,8 +67,9 @@ struct AH_JOB_GETSYSID {
   char *sysId;
 };
 
-static void AH_Job_GetSysId_FreeData(void *bp, void *p);
-static int AH_Job_GetSysId_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static void GWENHYWFAR_CB AH_Job_GetSysId_FreeData(void *bp, void *p);
+static int AH_Job_GetSysId_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+				   uint32_t guiid);
 static int AH_Job_GetSysId_NextMsg(AH_JOB *j);
 static int AH_Job_GetSysId_ExtractSysId(AH_JOB *j);
 
@@ -83,9 +87,10 @@ struct AH_JOB_UPDATEBANK {
   AB_ACCOUNT_LIST2 *accountList;
   int scanned;
 };
-static void AH_Job_UpdateBank_FreeData(void *bp, void *p);
+static void GWENHYWFAR_CB AH_Job_UpdateBank_FreeData(void *bp, void *p);
 
-static int AH_Job_UpdateBank_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static int AH_Job_UpdateBank_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+				     uint32_t guiid);
 
 
 
@@ -99,8 +104,9 @@ typedef struct AH_JOB_TESTVERSION AH_JOB_TESTVERSION;
 struct AH_JOB_TESTVERSION {
   AH_JOB_TESTVERSION_RESULT versionSupported;
 };
-static void AH_Job_TestVersion_FreeData(void *bp, void *p);
-static int AH_Job_TestVersion_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static void GWENHYWFAR_CB AH_Job_TestVersion_FreeData(void *bp, void *p);
+static int AH_Job_TestVersion_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+				      uint32_t guiid);
 
 
 
@@ -116,10 +122,13 @@ struct AH_JOB_GETSTATUS {
   GWEN_TIME *fromDate;
   GWEN_TIME *toDate;
 };
-static void AH_Job_GetStatus_FreeData(void *bp, void *p);
-static int AH_Job_GetStatus_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static void GWENHYWFAR_CB AH_Job_GetStatus_FreeData(void *bp, void *p);
+static int AH_Job_GetStatus_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+				    uint32_t guiid);
 static int AH_Job_GetStatus_Exchange(AH_JOB *j, AB_JOB *bj,
-                                     AH_JOB_EXCHANGE_MODE m);
+				     AH_JOB_EXCHANGE_MODE m,
+				     AB_IMEXPORTER_CONTEXT *ctx,
+				     uint32_t guiid);
 
 
 
@@ -132,11 +141,15 @@ typedef struct AH_JOB_TAN AH_JOB_TAN;
 struct AH_JOB_TAN {
   char *challenge;
   char *reference;
+  int tanMethod;
 };
-static void AH_Job_Tan_FreeData(void *bp, void *p);
-static int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static void GWENHYWFAR_CB AH_Job_Tan_FreeData(void *bp, void *p);
+static int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+			      uint32_t guiid);
 static int AH_Job_Tan_Exchange(AH_JOB *j, AB_JOB *bj,
-                               AH_JOB_EXCHANGE_MODE m);
+			       AH_JOB_EXCHANGE_MODE m,
+			       AB_IMEXPORTER_CONTEXT *ctx,
+			       uint32_t guiid);
 
 
 
@@ -145,12 +158,15 @@ static int AH_Job_Tan_Exchange(AH_JOB *j, AB_JOB *bj,
  *                             AH_Job_GetItanModes
  * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
  */
+#define AH_JOB_GETITANMODES_MAXMODES 20
 typedef struct AH_JOB_GETITANMODES AH_JOB_GETITANMODES;
 struct AH_JOB_GETITANMODES {
-  GWEN_TYPE_UINT32 modes;
+  int modeList[AH_JOB_GETITANMODES_MAXMODES+1];
+  int modeCount;
 };
-static void AH_Job_GetItanModes_FreeData(void *bp, void *p);
-static int AH_Job_GetItanModes_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx);
+static void GWENHYWFAR_CB AH_Job_GetItanModes_FreeData(void *bp, void *p);
+static int AH_Job_GetItanModes_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
+				       uint32_t guiid);
 
 
 
