@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: outbox_l.h 950 2006-02-22 19:39:02Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -32,7 +32,7 @@ typedef struct AH_OUTBOX AH_OUTBOX;
 #include <aqhbci/user.h>
 
 
-AH_OUTBOX *AH_Outbox_new(AH_HBCI *hbci);
+AH_OUTBOX *AH_Outbox_new(AH_HBCI *hbci, uint32_t guiid);
 void AH_Outbox_free(AH_OUTBOX *ob);
 void AH_Outbox_Attach(AH_OUTBOX *ob);
 
