@@ -51,9 +51,11 @@ static int AH_Provider_Execute(AB_PROVIDER *pro,
 			       uint32_t guiid);
 static int AH_Provider_ResetQueue(AB_PROVIDER *pro);
 static int AH_Provider_ExtendUser(AB_PROVIDER *pro, AB_USER *u,
-                                  AB_PROVIDER_EXTEND_MODE em);
+				  AB_PROVIDER_EXTEND_MODE em,
+				  GWEN_DB_NODE *dbBackend);
 static int AH_Provider_ExtendAccount(AB_PROVIDER *pro, AB_ACCOUNT *a,
-                                     AB_PROVIDER_EXTEND_MODE em);
+				     AB_PROVIDER_EXTEND_MODE em,
+				     GWEN_DB_NODE *dbBackend);
 static int AH_Provider_Update(AB_PROVIDER *pro,
                               uint32_t lastVersion,
                               uint32_t currentVersion);
