@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: user.h 1071 2006-09-30 11:05:50Z martin $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -25,8 +25,6 @@
  */
 /*@{*/
 
-#include <aqhbci/medium.h>
-
 #include <aqbanking/user.h>
 
 #include <gwenhywfar/db.h>
@@ -55,51 +53,16 @@ extern "C" {
  * indicates that some jobs are supported even when there is no UPD job
  * description for it */
 #define AH_USER_FLAGS_IGNORE_UPD              0x00000020
+
+/** forces use of SSLv3 for Pin/TAN mode */
+#define AH_USER_FLAGS_FORCE_SSL3              0x00000040
+
+/** do not encode message in BASE64 (needed for APO bank) */
+#define AH_USER_FLAGS_NO_BASE64               0x00000080
 /*@}*/
 
 
 
-/** @name HBCI TAN Methods
- *
- */
-/*@{*/
-/** single step PIN/TAN */
-#define AH_USER_TANMETHOD_SINGLE_STEP        0x00000001
-/** two step PIN/TAN, method 0 (990) */
-#define AH_USER_TANMETHOD_TWO_STEP_0         0x00000002
-/** two step PIN/TAN, method 1 (991) */
-#define AH_USER_TANMETHOD_TWO_STEP_1         0x00000004
-/** two step PIN/TAN, method 2 (992) */
-#define AH_USER_TANMETHOD_TWO_STEP_2         0x00000008
-/** two step PIN/TAN, method 3 (993) */
-#define AH_USER_TANMETHOD_TWO_STEP_3         0x00000010
-/** two step PIN/TAN, method 4 (994) */
-#define AH_USER_TANMETHOD_TWO_STEP_4         0x00000020
-/** two step PIN/TAN, method 5 (995) */
-#define AH_USER_TANMETHOD_TWO_STEP_5         0x00000040
-/** two step PIN/TAN, method 6 (996) */
-#define AH_USER_TANMETHOD_TWO_STEP_6         0x00000060
-/** two step PIN/TAN, method 7 (997) */
-#define AH_USER_TANMETHOD_TWO_STEP_7         0x00000080
-/** two step PIN/TAN, method 0 (900)  */
-#define AH_USER_TANMETHOD_TWO_STEP_00        0x00000100
-/** two step PIN/TAN, method 0 (901)  */
-#define AH_USER_TANMETHOD_TWO_STEP_01        0x00000400
-/** two step PIN/TAN, method 0 (902)  */
-#define AH_USER_TANMETHOD_TWO_STEP_02        0x00000800
-/** two step PIN/TAN, method 0 (903)  */
-#define AH_USER_TANMETHOD_TWO_STEP_03        0x00001000
-/** two step PIN/TAN, method 0 (904)  */
-#define AH_USER_TANMETHOD_TWO_STEP_04        0x00002000
-/** two step PIN/TAN, method 0 (905)  */
-#define AH_USER_TANMETHOD_TWO_STEP_05        0x00004000
-/** two step PIN/TAN, method 0 (906)  */
-#define AH_USER_TANMETHOD_TWO_STEP_06        0x00008000
-/** two step PIN/TAN, method 0 (907)  */
-#define AH_USER_TANMETHOD_TWO_STEP_07        0x00010000
-/*@}*/
-
-
 /** @name Functions for Flags and Status
  *
  */
@@ -107,18 +70,9 @@ extern "C" {
 
 AQHBCI_API
 void AH_User_Flags_toDb(GWEN_DB_NODE *db, const char *name,
-                        GWEN_TYPE_UINT32 flags);
+                        uint32_t flags);
 AQHBCI_API
-GWEN_TYPE_UINT32 AH_User_Flags_fromDb(GWEN_DB_NODE *db, const char *name);
-
-
-AQHBCI_API
-void AH_User_TanMethods_toDb(GWEN_DB_NODE *db, const char *name,
-                             GWEN_TYPE_UINT32 m);
-
-AQHBCI_API
-GWEN_TYPE_UINT32 AH_User_TanMethods_fromDb(GWEN_DB_NODE *db,
-                                           const char *name);
+uint32_t AH_User_Flags_fromDb(GWEN_DB_NODE *db, const char *name);
 
 
 typedef enum {
@@ -145,16 +99,16 @@ void AH_User_SetStatus(AB_USER *u, AH_USER_STATUS i);
  * never signs it's messages.
  */
 AQHBCI_API
-GWEN_TYPE_UINT32 AH_User_GetFlags(const AB_USER *u);
+uint32_t AH_User_GetFlags(const AB_USER *u);
 
 AQHBCI_API
-void AH_User_SetFlags(AB_USER *u, GWEN_TYPE_UINT32 flags);
+void AH_User_SetFlags(AB_USER *u, uint32_t flags);
 
 AQHBCI_API
-void AH_User_AddFlags(AB_USER *u, GWEN_TYPE_UINT32 flags);
+void AH_User_AddFlags(AB_USER *u, uint32_t flags);
 
 AQHBCI_API
-void AH_User_SubFlags(AB_USER *u, GWEN_TYPE_UINT32 flags);
+void AH_User_SubFlags(AB_USER *u, uint32_t flags);
 
 
 /*@}*/
@@ -164,36 +118,48 @@ void AH_User_SubFlags(AB_USER *u, GWEN_TYPE_UINT32 flags);
  *
  */
 /*@{*/
-AQHBCI_API
-GWEN_TYPE_UINT32 AH_User_GetTanMethods(const AB_USER *u);
 
 AQHBCI_API
-void AH_User_SetTanMethods(AB_USER *u, GWEN_TYPE_UINT32 m);
+const int *AH_User_GetTanMethodList(const AB_USER *u);
+AQHBCI_API
+int AH_User_GetTanMethodCount(const AB_USER *u);
+AQHBCI_API
+int AH_User_HasTanMethod(const AB_USER *u, int method);
+AQHBCI_API
+int AH_User_HasTanMethodOtherThan(const AB_USER *u, int method);
+AQHBCI_API
+void AH_User_AddTanMethod(AB_USER *u, int method);
+AQHBCI_API
+void AH_User_ClearTanMethodList(AB_USER *u);
 
 AQHBCI_API
-void AH_User_AddTanMethods(AB_USER *u, GWEN_TYPE_UINT32 m);
+int AH_User_GetSelectedTanMethod(const AB_USER *u);
+AQHBCI_API
+void AH_User_SetSelectedTanMethod(AB_USER *u, int i);
+
 
 AQHBCI_API
-void AH_User_SubTanMethods(AB_USER *u, GWEN_TYPE_UINT32 m);
+const char *AH_User_GetHttpContentType(const AB_USER *u);
+AQHBCI_API
+void AH_User_SetHttpContentType(AB_USER *u, const char *s);
 
 /*@}*/
 
 
 
-/** @name Medium Functions
- *
- */
-/*@{*/
 AQHBCI_API
-AH_MEDIUM *AH_User_GetMedium(const AB_USER *u);
+const char *AH_User_GetTokenType(const AB_USER *u);
 AQHBCI_API
-void AH_User_SetMedium(AB_USER *u, AH_MEDIUM *m);
+void AH_User_SetTokenType(AB_USER *u, const char *s);
+AQHBCI_API
+const char *AH_User_GetTokenName(const AB_USER *u);
+AQHBCI_API
+void AH_User_SetTokenName(AB_USER *u, const char *s);
+AQHBCI_API
+uint32_t AH_User_GetTokenContextId(const AB_USER *u);
+AQHBCI_API
+void AH_User_SetTokenContextId(AB_USER *u, uint32_t id);
 
-AQHBCI_API
-int AH_User_GetContextIdx(const AB_USER *u);
-AQHBCI_API
-void AH_User_SetContextIdx(AB_USER *u, int idx);
-/*@}*/
 
 
 /** @name Miscellanous Settings
@@ -208,6 +174,9 @@ AH_CRYPT_MODE AH_User_GetCryptMode(const AB_USER *u);
 AQHBCI_API
 void AH_User_SetCryptMode(AB_USER *u, AH_CRYPT_MODE m);
 
+int AH_User_GetRdhType(const AB_USER *u);
+void AH_User_SetRdhType(AB_USER *u, int i);
+
 AQHBCI_API
 const char *AH_User_GetPeerId(const AB_USER *u);
 AQHBCI_API
@@ -262,6 +231,27 @@ void AH_User_SetHttpUserAgent(AB_USER *u, const char *s);
 /*@}*/
 
 
+/** @name Passwords/Pins/Tans
+ *
+ */
+/*@{*/
+
+AQHBCI_API
+int AH_User_MkPasswdName(const AB_USER *u, GWEN_BUFFER *buf);
+
+AQHBCI_API
+int AH_User_MkPinName(const AB_USER *u, GWEN_BUFFER *buf);
+
+AQHBCI_API
+int AH_User_MkTanName(const AB_USER *u,
+		      const char *challenge,
+		      GWEN_BUFFER *buf);
+
+
+/*@}*/
+
+
+
 
 
 /*@}*/ /* defgroup */
