@@ -110,6 +110,21 @@ int getCert(AB_BANKING *ab,
 	    int argc,
 	    char **argv);
 
+int setHbciVersion(AB_BANKING *ab,
+		   GWEN_DB_NODE *dbArgs,
+		   int argc,
+		   char **argv);
+
+int addUserFlags(AB_BANKING *ab,
+		 GWEN_DB_NODE *dbArgs,
+		 int argc,
+		 char **argv);
+
+int subUserFlags(AB_BANKING *ab,
+		 GWEN_DB_NODE *dbArgs,
+		 int argc,
+		 char **argv);
+
 
 
 int test1(AB_BANKING *ab,
