@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: a_bankiniletter.cpp 950 2006-02-22 19:39:02Z aquamaniac $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -31,11 +31,11 @@
 
 
 ActionBankIniLetter::ActionBankIniLetter(Wizard *w)
-:WizardAction(w, "BankIniLetter", QWidget::tr("Verify Bank Key"))
-,_key(0) {
+:WizardAction(w, "BankIniLetter", QWidget::tr("Verify Bank Key")) {
   _iniLetterDialog=new IniLetter(false,
-                                 this,
-                                 "IniLetterDialog");
+				 w->getWizardInfo()->getProvider(),
+				 this,
+				 "IniLetterDialog");
   addWidget(_iniLetterDialog);
   _iniLetterDialog->show();
 
@@ -50,8 +50,6 @@ ActionBankIniLetter::ActionBankIniLetter(Wizard *w)
 
 
 ActionBankIniLetter::~ActionBankIniLetter() {
-  if (_key)
-    GWEN_CryptKey_free(_key);
 }
 
 
@@ -60,45 +58,17 @@ void ActionBankIniLetter::enter() {
   Wizard *w;
   WizardInfo *wi;
   AB_USER *u;
-  AH_MEDIUM *m;
-  int rv;
-  GWEN_CRYPTKEY *key;
 
   setNextEnabled(false);
   w=getWizard();
   wi=w->getWizardInfo();
   u=wi->getUser();
-  m=wi->getMedium();
+  assert(u);
 
-  /* mount medium (if necessary) */
-  if (!AH_Medium_IsMounted(m)) {
-    rv=AH_Medium_Mount(m);
-    if (rv) {
-      DBG_ERROR(0, "Could not mount medium (%d)", rv);
-      return;
-    }
-  }
-
-  /* select context of the user */
-  rv=AH_Medium_SelectContext(m, AH_User_GetContextIdx(u));
-  if (rv) {
-    DBG_ERROR(0, "Could not select context (%d)", rv);
-    return;
-  }
-
-  /* get key */
-  key=AH_Medium_GetPubSignKey(m);
-  if (!key)
-    key=AH_Medium_GetPubCryptKey(m);
-  assert(key);
-
-  if (!_iniLetterDialog->init(QString::fromUtf8(wi->getBankId().c_str()),
-                              key)) {
+  if (!_iniLetterDialog->init(u)) {
     DBG_ERROR(0, "Could not init dialog");
-    GWEN_CryptKey_free(key);
     return;
   }
-  _key=key;
 }
 
 
@@ -136,6 +106,6 @@ void ActionBankIniLetter::slotPrint() {
 
 
 
-
+#include "a_bankiniletter.moc"
 
 
