@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: a_selectfile.cpp 764 2006-01-13 14:00:00Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -61,16 +61,22 @@ void ActionSelectFile::slotFileButtonClicked() {
   QString filename;
   QString title;
 
-  if (_mustExist)
+  if (_mustExist) {
     title=tr("Enter existing medium file name");
-  else
+    filename=QFileDialog::getOpenFileName(_realDialog->fileNameEdit->text(),
+					  QString::null,
+					  this,
+					  "slotFileButtonClicked",
+					  title);
+  }
+  else {
     title=tr("Enter new medium file name");
-
-  filename=QFileDialog::getSaveFileName(_realDialog->fileNameEdit->text(),
-                                        QString::null,
-                                        this,
-                                        "slotFileButtonClicked",
-                                        title);
+    filename=QFileDialog::getSaveFileName(_realDialog->fileNameEdit->text(),
+					  QString::null,
+					  this,
+					  "slotFileButtonClicked",
+					  title);
+  }
   if (!filename.isEmpty())
     _realDialog->fileNameEdit->setText(filename);
 }
@@ -108,13 +114,15 @@ bool ActionSelectFile::apply() {
   if (s.empty())
     return false;
   getWizard()->getWizardInfo()->setMediumName(s);
+  if (!_mustExist)
+    getWizard()->getWizardInfo()->setMediumType("ohbci");
   return true;
 }
 
 
 
 
-
+#include "a_selectfile.moc"
 
 
 
