@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: provider_p.h 865 2006-01-27 03:04:21Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -17,14 +17,16 @@
 
 int AN_Provider_Init(AB_PROVIDER *pro, GWEN_DB_NODE *dbData);
 int AN_Provider_Fini(AB_PROVIDER *pro, GWEN_DB_NODE *dbData);
-int AN_Provider_UpdateJob(AB_PROVIDER *pro, AB_JOB *j);
-int AN_Provider_AddJob(AB_PROVIDER *pro, AB_JOB *j);
+int AN_Provider_UpdateJob(AB_PROVIDER *pro, AB_JOB *j, uint32_t guiid);
+int AN_Provider_AddJob(AB_PROVIDER *pro, AB_JOB *j, uint32_t guiid);
 int AN_Provider_ResetQueue(AB_PROVIDER *pro);
-int AN_Provider_Execute(AB_PROVIDER *pro, AB_IMEXPORTER_CONTEXT *ctx);
+int AN_Provider_Execute(AB_PROVIDER *pro,
+			AB_IMEXPORTER_CONTEXT *ctx,
+			uint32_t guiid);
 int AN_Provider_ExtendUser(AB_PROVIDER *pro, AB_USER *u,
-                           AB_PROVIDER_EXTEND_MODE em);
+			   AB_PROVIDER_EXTEND_MODE em);
 int AN_Provider_ExtendAccount(AB_PROVIDER *pro, AB_ACCOUNT *a,
-                              AB_PROVIDER_EXTEND_MODE em);
+			      AB_PROVIDER_EXTEND_MODE em);
 
 #endif
 
