@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: account.h 764 2006-01-13 14:00:00Z cstim $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -23,7 +23,8 @@ extern "C" {
 
 
 AQOFXCONNECT_API void AO_Account_Extend(AB_ACCOUNT *a, AB_PROVIDER *pro,
-                                        AB_PROVIDER_EXTEND_MODE em);
+					AB_PROVIDER_EXTEND_MODE em,
+					GWEN_DB_NODE *dbBackend);
 
 AQOFXCONNECT_API int AO_Account_GetMaxPurposeLines(const AB_ACCOUNT *a);
 AQOFXCONNECT_API void AO_Account_SetMaxPurposeLines(AB_ACCOUNT *a, int i);
