@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: at.c 276 2005-04-13 22:18:59Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -38,13 +35,20 @@ GWEN_INHERIT(AB_BANKINFO_PLUGIN, AB_BANKINFO_PLUGIN_AT);
 GWEN_PLUGIN *bankinfo_at_factory(GWEN_PLUGIN_MANAGER *pm,
                                  const char *name,
                                  const char *fileName) {
-  return GWEN_Plugin_new(pm, name, fileName);
+  GWEN_PLUGIN *pl;
+
+  pl=AB_Plugin_BankInfo_new(pm, name, fileName);
+  assert(pl);
+
+  AB_Plugin_BankInfo_SetFactoryFn(pl, AB_Plugin_BankInfoAT_Factory);
+
+  return pl;
 }
 
 
 
 /* interface to bankinfo plugin */
-AB_BANKINFO_PLUGIN *at_factory(AB_BANKING *ab, GWEN_DB_NODE *db){
+AB_BANKINFO_PLUGIN *AB_Plugin_BankInfoAT_Factory(GWEN_PLUGIN *pl, AB_BANKING *ab, GWEN_DB_NODE *db){
   AB_BANKINFO_PLUGIN *bip;
   AB_BANKINFO_PLUGIN_AT *bde;
 
@@ -60,7 +64,7 @@ AB_BANKINFO_PLUGIN *at_factory(AB_BANKING *ab, GWEN_DB_NODE *db){
 
 
 
-void AB_BankInfoPluginAT_FreeData(void *bp, void *p){
+void GWENHYWFAR_CB AB_BankInfoPluginAT_FreeData(void *bp, void *p){
   AB_BANKINFO_PLUGIN_AT *bde;
 
   bde=(AB_BANKINFO_PLUGIN_AT*)p;
