@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: csv_p.h 566 2005-08-23 06:25:03Z aquamaniac $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -25,28 +25,57 @@ struct AH_IMEXPORTER_CSV {
 };
 
 
-AB_IMEXPORTER* csv_factory(AB_BANKING *ab, GWEN_DB_NODE *db);
-void AH_ImExporterCSV_FreeData(void *bp, void *p);
+AQBANKING_EXPORT
+GWEN_PLUGIN *imexporters_csv_factory(GWEN_PLUGIN_MANAGER *pm,
+				     const char *name,
+				     const char *fileName);
 
+
+static
+AB_IMEXPORTER *AB_Plugin_ImExporterCSV_Factory(GWEN_PLUGIN *pl,
+					       AB_BANKING *ab,
+					       GWEN_DB_NODE *db);
+
+static
+void GWENHYWFAR_CB AH_ImExporterCSV_FreeData(void *bp, void *p);
+
+static
 int AH_ImExporterCSV_Import(AB_IMEXPORTER *ie,
                             AB_IMEXPORTER_CONTEXT *ctx,
-                            GWEN_BUFFEREDIO *bio,
-                            GWEN_DB_NODE *params);
+                            GWEN_IO_LAYER *io,
+			    GWEN_DB_NODE *params,
+			    uint32_t guiid);
+
+static
 int AH_ImExporterCSV_Export(AB_IMEXPORTER *ie,
                             AB_IMEXPORTER_CONTEXT *ctx,
-                            GWEN_BUFFEREDIO *bio,
-                            GWEN_DB_NODE *params);
+                            GWEN_IO_LAYER *io,
+			    GWEN_DB_NODE *params,
+			    uint32_t guiid);
 
-int AH_ImExporterCSV_CheckFile(AB_IMEXPORTER *ie, const char *fname);
+static
+int AH_ImExporterCSV_CheckFile(AB_IMEXPORTER *ie, const char *fname, uint32_t guiid);
 
 
+static
 int AH_ImExporterCSV__ImportFromGroup(AB_IMEXPORTER_CONTEXT *ctx,
                                       GWEN_DB_NODE *db,
-                                      GWEN_DB_NODE *dbParams);
+				      GWEN_DB_NODE *dbParams,
+				      uint32_t guiid);
 
-int AH_ImExporterCSV__Transform_Var(GWEN_DB_NODE *db, int level);
+static
+int AH_ImExporterCSV__ExportTransactions(AB_IMEXPORTER *ie,
+					 AB_IMEXPORTER_CONTEXT *ctx,
+					 GWEN_IO_LAYER *io,
+					 GWEN_DB_NODE *params,
+					 uint32_t guiid);
 
-int AH_ImExporterCSV__Transform_Group(GWEN_DB_NODE *db, int level);
+static
+int AH_ImExporterCSV__ExportNotedTransactions(AB_IMEXPORTER *ie,
+					      AB_IMEXPORTER_CONTEXT *ctx,
+					      GWEN_IO_LAYER *io,
+					      GWEN_DB_NODE *params,
+					      uint32_t guiid);
 
 
 #endif /* AQHBCI_IMEX_CSV_P_H */
