@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: swift_p.h 566 2005-08-23 06:25:03Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -26,20 +23,36 @@ struct AH_IMEXPORTER_SWIFT {
 };
 
 
-AB_IMEXPORTER* swift_factory(AB_BANKING *ab, GWEN_DB_NODE *db);
-void AH_ImExporterSWIFT_FreeData(void *bp, void *p);
+AQBANKING_EXPORT
+GWEN_PLUGIN *imexporters_swift_factory(GWEN_PLUGIN_MANAGER *pm,
+				       const char *name,
+				       const char *fileName);
 
+static
+AB_IMEXPORTER *AB_Plugin_ImExporterSWIFT_Factory(GWEN_PLUGIN *pl,
+						 AB_BANKING *ab,
+						 GWEN_DB_NODE *db);
+
+
+static
+void GWENHYWFAR_CB AH_ImExporterSWIFT_FreeData(void *bp, void *p);
+
+static
 int AH_ImExporterSWIFT_Import(AB_IMEXPORTER *ie,
                               AB_IMEXPORTER_CONTEXT *ctx,
-                              GWEN_BUFFEREDIO *bio,
-                              GWEN_DB_NODE *params);
+			      GWEN_IO_LAYER *io,
+			      GWEN_DB_NODE *params,
+			      uint32_t guiid);
 
-int AH_ImExporterSWIFT_CheckFile(AB_IMEXPORTER *ie, const char *fname);
+static
+int AH_ImExporterSWIFT_CheckFile(AB_IMEXPORTER *ie, const char *fname, uint32_t guiid);
 
 
+static
 int AH_ImExporterSWIFT__ImportFromGroup(AB_IMEXPORTER_CONTEXT *ctx,
                                         GWEN_DB_NODE *db,
-                                        GWEN_DB_NODE *dbParams);
+					GWEN_DB_NODE *dbParams,
+					uint32_t guiid);
 
 
 #endif /* AQHBCI_IMEX_SWIFT_P_H */
